# Generated by Django 3.2 on 2023-02-17 09:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0008_evalpreassessment_evalpreassessmenta_evalpreassessmentb'),
    ]

    operations = [
        migrations.AlterField(
            model_name='evalpreassessmentb',
            name='scored',
            field=models.CharField(blank=True, choices=[('one', 'Demonstrated Competence at a High Level'), ('two', 'Goal Achived'), ('three', 'Goal not Reached')], max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='evalselfdeta',
            name='parameter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdeta', to='perform.evalplanninga'),
        ),
        migrations.AlterField(
            model_name='evalselfdetb',
            name='parameter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdetb', to='perform.evalplanningb'),
        ),
    ]
