# Generated by Django 3.2 on 2023-02-17 14:02

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('custom', '0013_alter_unit_options'),
        ('employee', '0023_alter_photo_image'),
        ('perform', '0009_auto_20230217_1813'),
    ]

    operations = [
        migrations.AddField(
            model_name='eval',
            name='employeeeval',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalevaluator', to='employee.employee'),
        ),
        migrations.AddField(
            model_name='eval',
            name='positioneval',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalevaluator', to='custom.position'),
        ),
        migrations.AddField(
            model_name='eval',
            name='uniteval',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalevaluator', to='custom.unit'),
        ),
        migrations.AlterField(
            model_name='evaldeta',
            name='parameter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldeta', to='perform.evalplanninga'),
        ),
        migrations.AlterField(
            model_name='evaldetb',
            name='parameter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldetb', to='perform.evalplanningb'),
        ),
    ]
