{% extends "main/layout.html" %}
{% load crispy_forms_tags %}
{% block content %}
<div class="breadcrumb-holder">
	<div class="container-fluid">
		<ul class="breadcrumb">
		{% if page == 'list' %}
			<li class="breadcrumb-item"><a href="{% url 'eval-self-list' %}">LISTA AVALIASAUN PESSOAL</a></li>
		{% else %}
			<li class="breadcrumb-item"><a href="{% url 'eval-self-detail' eval.hashed %}">LISTA AVALIASAUN </a></li>
		{% endif %}
			<li class="breadcrumb-item active">{{ legend|upper }}</li>
		</ul>
	</div>
</div>
<div class="container-fluid"><br/>
	<div class="row">
		<div class="col-sm-12">
			<div class="card shadow-lg border-info rounded">
				<div class="card-header">{{ legend|upper }}</div>
				<div class="card-body">
					{% crispy form %}
				</div> <!--end card-body-->
			</div> <!--end card-->
		</div> <!--end col-->
	</div> <!--end row-->
</div>
{% endblock %}
{% block scripts %}
{% endblock %}