# Generated by Django 3.2 on 2023-02-18 06:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0011_evalplanning_date'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalplanning',
            old_name='date',
            new_name='ind_date',
        ),
        migrations.AddField(
            model_name='evalplanning',
            name='obj_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]
