# Generated by Django 3.2 on 2022-12-11 11:44

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('custom', '0012_alter_department_leader'),
        ('employee', '0018_employee_pin'),
        ('contract', '0014_alter_contract_file'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Eval',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('score_a', models.IntegerField(blank=True, null=True)),
                ('score_b', models.IntegerField(blank=True, null=True)),
                ('total', models.IntegerField(blank=True, null=True)),
                ('is_lock', models.BooleanField(default=False, null=True)),
                ('is_finish', models.BooleanField(default=False, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='contract.category')),
                ('department', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='custom.department')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='employee.employee')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='custom.position')),
            ],
        ),
        migrations.CreateModel(
            name='EvalChoice',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True)),
                ('score', models.IntegerField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='EvalSelf',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('comments', models.TextField(blank=True, null=True)),
                ('is_lock', models.BooleanField(default=False, null=True)),
                ('is_finish', models.BooleanField(default=False, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='contract.category')),
                ('department', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='custom.department')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='employee.employee')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='custom.position')),
            ],
        ),
        migrations.CreateModel(
            name='EvalType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='EvalYear',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('year', models.IntegerField(blank=True, null=True)),
                ('is_active', models.BooleanField(default=False, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='ParameterA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True)),
                ('measure', models.TextField(blank=True, null=True)),
                ('criteria', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='ParameterB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('area', models.CharField(blank=True, max_length=100, null=True)),
                ('indicator', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Evaluator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaluator', to='employee.employee')),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaluator', to='perform.eval')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaluator', to='custom.position')),
                ('unit', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaluator', to='custom.unit')),
            ],
        ),
        migrations.CreateModel(
            name='EvalSelfDetB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments_a', models.TextField(blank=True, null=True)),
                ('comments_b', models.TextField(blank=True, null=True)),
                ('comments_c', models.TextField(blank=True, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdetb', to='perform.evalself')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdetb', to='perform.parameterb')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalSelfDetA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments_a', models.TextField(blank=True, null=True, verbose_name='Goal Exceeded')),
                ('comments_b', models.TextField(blank=True, null=True, verbose_name='Goal Achieved')),
                ('comments_c', models.TextField(blank=True, null=True, verbose_name='Goal Not Reached')),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdeta', to='perform.evalself')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalselfdeta', to='perform.parametera')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AddField(
            model_name='evalself',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='perform.evaltype'),
        ),
        migrations.AddField(
            model_name='evalself',
            name='unit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='custom.unit'),
        ),
        migrations.AddField(
            model_name='evalself',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='evalself',
            name='year',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalself', to='perform.evalyear'),
        ),
        migrations.CreateModel(
            name='EvalFinalScore',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('a', models.IntegerField(blank=True, null=True)),
                ('b', models.IntegerField(blank=True, null=True)),
                ('c', models.IntegerField(blank=True, null=True)),
                ('d', models.IntegerField(blank=True, null=True)),
                ('e', models.IntegerField(blank=True, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalfinalscore', to='perform.eval')),
            ],
        ),
        migrations.CreateModel(
            name='EvalDetB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments', models.TextField(blank=True, null=True, verbose_name='Komentariu')),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('choice', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldetb', to='perform.evalchoice')),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldetb', to='perform.eval')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldetb', to='perform.parameterb')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalDetA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comments', models.TextField(blank=True, null=True, verbose_name='Komentariu')),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('choice', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldeta', to='perform.evalchoice')),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldeta', to='perform.eval')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldeta', to='perform.parametera')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalDate',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_a_1', models.DateField(blank=True, null=True)),
                ('date_a_2', models.DateField(blank=True, null=True)),
                ('date_b_1', models.DateField(blank=True, null=True)),
                ('date_b_2', models.DateField(blank=True, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evaldate', to='perform.eval')),
            ],
        ),
        migrations.AddField(
            model_name='eval',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='perform.evaltype'),
        ),
        migrations.AddField(
            model_name='eval',
            name='unit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='custom.unit'),
        ),
        migrations.AddField(
            model_name='eval',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='eval',
            name='year',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eval', to='perform.evalyear'),
        ),
    ]
