# Generated by Django 3.2 on 2023-03-07 01:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0019_auto_20230307_0950'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='evalplanning',
            name='comment_next_evaluation',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='just_non_evaluation',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='outstanding_perf',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='recognition_merit',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='unsatisfactory_perf_beh',
        ),
        migrations.RemoveField(
            model_name='evalplanning',
            name='unsatisfactory_perf_obj',
        ),
    ]
