from django.contrib import admin
from .models import *

admin.site.register(EvalYear)
admin.site.register(EvalType)
admin.site.register(EvalChoice)
admin.site.register(ParameterA)
admin.site.register(ParameterB)
admin.site.register(Eval)
admin.site.register(Evaluator)
admin.site.register(EvalFinalScore)
admin.site.register(EvalDate)
admin.site.register(EvalDetA)
admin.site.register(EvalDetB)
admin.site.register(EvalSelf)
admin.site.register(EvalSelfDetA)
admin.site.register(EvalSelfDetB)
admin.site.register(EvalChoicePlanning)
admin.site.register(EvalPlanning)
admin.site.register(EvalPlanningA)
admin.site.register(EvalPlanningB)
admin.site.register(EvalPreAssessment)
admin.site.register(EvalPreAssessmentA)
admin.site.register(EvalPreAssessmentB)