# Generated by Django 3.2 on 2023-02-16 13:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0003_evalplanninga_evalplanningb'),
    ]

    operations = [
        migrations.AddField(
            model_name='evalplanninga',
            name='eval_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]
