# Generated by Django 3.2 on 2023-02-18 09:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0017_auto_20230218_1719'),
    ]

    operations = [
        migrations.AddField(
            model_name='eval',
            name='emp_beh_date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='eval',
            name='emp_obj_date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='eval',
            name='empeval_beh_date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='eval',
            name='empeval_obj_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]
