# Generated by Django 3.2 on 2023-02-18 07:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0013_auto_20230218_1557'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalpreassessment',
            old_name='eval_date',
            new_name='eval_ind_date',
        ),
        migrations.AddField(
            model_name='evalpreassessment',
            name='comments',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='evalpreassessment',
            name='eval_obj_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]
