# Generated by Django 3.2 on 2023-02-16 09:42

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('custom', '0013_alter_unit_options'),
        ('contract', '0017_contract_file_end'),
        ('employee', '0023_alter_photo_image'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('perform', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='EvalChoicePlanning',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True)),
                ('score', models.IntegerField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='EvalPlanning',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('objective', models.TextField(blank=True, null=True, verbose_name='Objectives')),
                ('is_lock', models.BooleanField(default=False, null=True)),
                ('is_finish', models.BooleanField(default=False, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningemp', to='contract.category')),
                ('department', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningeval', to='custom.department')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningemp', to='employee.employee')),
                ('employeeeval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningempeval', to='employee.employee')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningemp', to='custom.position')),
                ('positioneval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningempeval', to='custom.position')),
                ('type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningeval', to='perform.evaltype')),
                ('unit', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningemp', to='custom.unit')),
                ('uniteval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningempeval', to='custom.unit')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='planningeval', to='perform.evalyear')),
            ],
        ),
    ]
