# Generated by Django 3.2 on 2023-03-10 00:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0023_rename_year_evalmonth_month'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='evaltype',
            name='month',
        ),
    ]
