{% extends "main/layout.html" %}
{% block content %}
<div class="breadcrumb-holder">
    <div class="container-fluid">
        <ul class="breadcrumb">
            <li class="breadcrumb-item active">{{ legend|upper }}</li>
        </ul>
    </div>
</div>
<div class="container-fluid"><br/>
    <div class="row">
        <div class="col-sm-12">
            <div class="card shadow-lg border-info rounded">
                <div class="card-header border-primary text-center">
                    <h2>{{ legend|upper }}</h2>
                </div>
                <div class="card-body">
                    <a class="btn btn-sm btn-success mb-1" href="{% url 'c-eval-list' %}">Lista Avaliasaun <i class="fa fa-list-ul"></i></a>
                    {% if group == 'hr' %}
                    <a class="btn btn-sm btn-secondary mb-1" href="{% url 'eval-conf-dash' %}">Konfigurasaun <i class="fa fa-gear"></i></a>
                    {% endif %}
                    <a class="btn btn-sm btn-info mb-1" href="{% url 'eval-self-unit-list' %}">Self Assesment <i class="fa fa-list"></i></a>
                    <table class="table table-sm table-striped" id="#" width="100%" cellspacing="0">
                        <thead>
                            <tr align="center">
                                <th class="text-left">Categoria</th>
                                <th># Funsionariu</th>
                                <th># Avaliadu</th>
                                <th># Falta</th>
                            </tr>
                        </thead>
                        <tbody>
                        {% for obj in objects %}
                            <tr align="center">
                                <td class="text-left">
                                    <a href="{% url 'c-eval-cat-list' obj.0.id %}">{{ obj.0.name }}</a>
                                </td>
                                <td>{{ obj.1 }}</td>
                                <td>{{ obj.2 }}</td>
                                <td>{{ obj.3 }}</td>
                                <td>
                                </td>
                            </tr>
                        {% endfor %}
                        </tbody>
                    </table>
                </div> <!--end card-body-->
            </div> <!--end card-->
        </div> <!--end col-->
    </div> <!--end row-->
</div>
{% endblock %}
{% block scripts %}
	<script type="text/javascript">
		$(document).ready(function() {
			$('#example').DataTable();
		} );
	</script>
{% endblock %}