# Generated by Django 3.2 on 2023-03-10 00:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0022_auto_20230310_0923'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalmonth',
            old_name='year',
            new_name='month',
        ),
    ]
