# Generated by Django 3.2 on 2023-02-17 02:16

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('employee', '0023_alter_photo_image'),
        ('contract', '0017_contract_file_end'),
        ('custom', '0013_alter_unit_options'),
        ('perform', '0007_auto_20230217_0014'),
    ]

    operations = [
        migrations.CreateModel(
            name='EvalPreAssessment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('objective', models.TextField(blank=True, null=True, verbose_name='Objectives')),
                ('is_lock', models.BooleanField(default=False, null=True)),
                ('is_finish', models.BooleanField(default=False, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassemp', to='contract.category')),
                ('department', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreass', to='custom.department')),
                ('employee', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassemp', to='employee.employee')),
                ('employeeeval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassempeval', to='employee.employee')),
                ('position', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassemp', to='custom.position')),
                ('positioneval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassempeval', to='custom.position')),
                ('type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreass', to='perform.evaltype')),
                ('unit', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassemp', to='custom.unit')),
                ('uniteval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassempeval', to='custom.unit')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreass', to='perform.evalyear')),
            ],
        ),
        migrations.CreateModel(
            name='EvalPreAssessmentB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('scored', models.CharField(blank=True, choices=[('one', 'Demonstrated Competence at a High Level (Explain)'), ('two', 'Goal Achived'), ('three', 'Goal not Reached')], max_length=100, null=True)),
                ('enter_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassb', to='perform.evalpreassessment')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassbobjective', to='perform.evalplanningb')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('usereval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassbuser', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalPreAssessmentA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('scored', models.CharField(blank=True, choices=[('one', 'Goal Exceeded (Explain)'), ('two', 'Goal Achived (Explain)'), ('three', 'Goal not Reached (Explain)')], max_length=100, null=True)),
                ('enter_date', models.DateField(blank=True, null=True)),
                ('eval_date', models.DateField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassa', to='perform.evalpreassessment')),
                ('plan_objective', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassaobjective', to='perform.evalplanninga')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('usereval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalpreassauser', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
