# Generated by Django 3.2 on 2023-02-16 14:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0004_evalplanninga_eval_date'),
    ]

    operations = [
        migrations.AddField(
            model_name='evalplanninga',
            name='enter_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]
