# Generated by Django 3.2 on 2023-03-10 10:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0024_remove_evaltype_month'),
    ]

    operations = [
        migrations.AddField(
            model_name='evalplanning',
            name='month',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
