# Generated by Django 3.2 on 2023-02-16 09:58

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('perform', '0002_evalchoiceplanning_evalplanning'),
    ]

    operations = [
        migrations.CreateModel(
            name='EvalPlanningB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('progress', models.TextField(blank=True, null=True)),
                ('dificulties', models.TextField(blank=True, null=True)),
                ('need_improv', models.TextField(blank=True, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalplanningb', to='perform.evalplanning')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalplanningb', to='perform.parameterb')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalPlanningA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('goals', models.TextField(blank=True, null=True, verbose_name='Goas/Activities')),
                ('measuring', models.TextField(blank=True, null=True, verbose_name='Measuring Indicator')),
                ('criteria', models.TextField(blank=True, null=True, verbose_name='Criteria for Overcoming')),
                ('score', models.DecimalField(blank=True, decimal_places=2, max_digits=11, null=True)),
                ('progress', models.TextField(blank=True, null=True, verbose_name='Progress')),
                ('dificulties', models.TextField(blank=True, null=True, verbose_name='Dificulties')),
                ('need_improv', models.TextField(blank=True, null=True, verbose_name='Need Improvement')),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalplanninga', to='perform.evalplanning')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
