# Generated by Django 3.2 on 2023-02-18 08:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0016_auto_20230218_1718'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalself',
            old_name='eval_beh_date',
            new_name='beh_date',
        ),
        migrations.RenameField(
            model_name='evalself',
            old_name='eval_ind_date',
            new_name='ind_date',
        ),
    ]
