# Generated by Django 3.2 on 2023-02-16 14:05

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('perform', '0005_evalplanninga_enter_date'),
    ]

    operations = [
        migrations.AddField(
            model_name='evalplanninga',
            name='usereval',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalplanningauser', to=settings.AUTH_USER_MODEL),
        ),
    ]
