# Generated by Django 3.2 on 2023-02-18 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0015_rename_eval_obj_date_evalpreassessment_eval_beh_date'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalself',
            old_name='eval_date',
            new_name='eval_beh_date',
        ),
        migrations.AddField(
            model_name='evalself',
            name='eval_ind_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]
