# Generated by Django 3.2 on 2023-03-07 01:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0020_auto_20230307_1026'),
    ]

    operations = [
        migrations.AddField(
            model_name='eval',
            name='comment_next_evaluation',
            field=models.TextField(blank=True, null=True, verbose_name='Expectations, Conditions And / Or Requirements for Personal And Professional Development'),
        ),
        migrations.AddField(
            model_name='eval',
            name='just_non_evaluation',
            field=models.TextField(blank=True, null=True, verbose_name='Jusitification of Non-Evaluation'),
        ),
        migrations.AddField(
            model_name='eval',
            name='outstanding_perf',
            field=models.TextField(blank=True, null=True, verbose_name='Justification Of Outstanding Performance'),
        ),
        migrations.AddField(
            model_name='eval',
            name='recognition_merit',
            field=models.TextField(blank=True, null=True, verbose_name='Recognition of Merit (Outstanding Performance)'),
        ),
        migrations.AddField(
            model_name='eval',
            name='unsatisfactory_perf_beh',
            field=models.TextField(blank=True, null=True, verbose_name='Justification Of Unsatisfactory Performance - Professional Behaviors'),
        ),
        migrations.AddField(
            model_name='eval',
            name='unsatisfactory_perf_obj',
            field=models.TextField(blank=True, null=True, verbose_name='Justification Of Unsatisfactory Performance - Individual Objectives'),
        ),
    ]
